'use strict';

// Global Header Functions
var csHeader = {
	/**
	* Stores cached elements
	**/
	cache: {
	},
	/**
	* @function
	* Initialises all objects required for the Header Functions
	* @param {jQuery Element} el - jQuery Header Element
	*/
	initCache: function(el) {
		this.cache = {
			element: el,
			skeleton: el.find('.header_skeleton'),
			triggers: jQuery('[data-js-overview-menu-trigger]'),
			header_trigger: el.find('[data-js-overview-menu-trigger]'),
			overview: {
				menu: jQuery('[data-js-overview-menu]'),
				trigger: jQuery('[data-js-overview-menu] [data-js-overview-menu-trigger]')
			},
			offcanvasState: false,
			adminBar: jQuery('#wpadminbar')
		};
	},
	/**
	* @function
	* Initialises the Header
	*/
	init: function() {
		this.initCache(jQuery('header.header'));

		this.cache.triggers.on('click', function(e) {
			e.preventDefault();
			
			var leftOffset =	csHeader.cache.header_trigger.offset().left -
								(csHeader.cache.header_trigger.outerWidth(true) -
								csHeader.cache.header_trigger.outerWidth());
			
			csHeader.cache.overview.trigger.css({
													position: 'absolute',
													top: csHeader.cache.header_trigger.position().top,
													left: leftOffset
												});
			
			jQuery('body, html').toggleClass('menu_open');
			
			csHeader.toggleOffcanvas();
		});
		
		if (this.cache.adminBar.length) {

			jQuery(document).mousemove(function(e) {
				var vertical = e.pageY;
				
				if (vertical <= 40) {
					csHeader.showAdminBar();
				} else {
					csHeader.hideAdminBar();
				}
			});

			this.cache.adminBar.on({
				mouseenter: function() {
					
				},
				mouseleave: function() {
					csHeader.showAdminBar();
				}
			});
		}
	},
	/**
	* @function
	* Show the Mobile Menu
	*/
	showOffcanvas: function() {
		this.cache.overview.menu.addClass('active');
		this.cache.header_trigger.addClass('hide_icon');
		this.cache.overview.trigger.removeClass('hide_icon');
		
		this.cache.overview.menu.removeClass('inactive');
		this.cache.skeleton.addClass('light_for_menu');
		
		jQuery('html').on('scroll touchmove mousewheel', function() {
			jQuery('html').css('overflow', 'hidden');
		});
	},
	/**
	* @function
	* Hide Mobile menu
	*/
	hideOffcanvas: function() {
		this.cache.overview.menu.removeClass('active');
		this.cache.header_trigger.removeClass('hide_icon');
		this.cache.overview.trigger.addClass('hide_icon');
		
		this.cache.skeleton.removeClass('light_for_menu');
		this.cache.overview.menu.addClass('inactive');
		
		jQuery('html').on('scroll touchmove mousewheel', function() {
			jQuery('html').css('overflow', 'auto');
		});
	},
	/**
	* @function
	* Toggle Mobile Menu
	*/
	toggleOffcanvas: function() {
		this.cache.offcanvasState = !this.cache.offcanvasState;
		
		if (this.cache.offcanvasState) {
			this.showOffcanvas();
		} else {
			this.hideOffcanvas();
		}
	},
	/**
	* @function
	* Hide WP Admin Bar
	*/
	hideAdminBar: function() {
		var self = this;
		
		if (self.cache.adminBar.find('li.hover').length) {
			return;
		}
		
		setTimeout(function() {
			self.cache.adminBar.removeClass('active');
		}, 1500);
	},
	/**
	* @function
	* Show WP Admin Bar
	*/
	showAdminBar: function() {
		this.cache.adminBar.addClass('active');
	},
	/**
	* @function
	* Get Height of the Header
	*/
	getHeaderHeight: function() {
		return this.cache.skeleton.length ? this.cache.skeleton.outerHeight() : 0;
	},
	/**
	* @function
	* Check if Transparent Header
	*/
	isTransparentHeader: function() {
		return this.cache.skeleton ? this.cache.skeleton.hasClass('transparent') : false;
	}
	
};

window.csHeader = csHeader;

jQuery(function() {
	csHeader.init();
});
