'use strict';
(function() {
	// Global Banner Functions
	var csAJAXPagination = {
		/**
		* Stores cached elements
		**/
		cache: {
			scrollContainer: jQuery('[data-infinite-scroll]'),
			pagination: jQuery('.pagination-next'),
			loadTrigger: jQuery('[data-infinite-scroll-trigger]'),
			loading: false
		},
		/**
		* @function
		* Initialises the Banner
		*/
		init: function() {
			this.cache.pagination.hide();

			this.cache.loadTrigger.on('click', (e) => {
				e.preventDefault();

				if (this.cache.loading === true) {
					return;
				}

				this.loadNextPage();
			});

			window.addEventListener('scroll', () => {
				if (!this.cache.loading && this.isVisible(this.cache.loadTrigger)) {
					this.cache.loadTrigger.click();
				}
			});
		},
		isVisible: function(elem) {
			var docViewTop = jQuery(window).scrollTop();
			var docViewBottom = docViewTop + jQuery(window).height();

			var elemTop = elem.offset().top;
			var elemBottom = elemTop + elem.height();

			return ((elemBottom <= docViewBottom) && (elemTop >= docViewTop));
		},
		loadNextPage: function() {
			var scrollURL = this.cache.pagination.attr('href');

			jQuery.ajax({
				type: 'GET',
				url: scrollURL,
				beforeSend: () => {
					this.cache.loading = true;

					this.cache.loadTrigger.prepend('<i class="fa fa-circle-notch fa-spin" aria-hidden="true"></i>');
				},
				success: (data) => {

					// remove loading feedback
					var filteredData = jQuery(data).find('[data-infinite-scroll] > .cell');

					filteredData.find('.tile__vehicle .tile__vehicle-slider').each((index, element) => {
						window.csVehicleTile.initSliderOnEl(jQuery(element));
						jQuery(element).slick('resize');
						if (jQuery(element).find('.cs__image').length) {
							new Foundation.Interchange(jQuery(element).find('.cs__image'));
						}
					});

					filteredData.appendTo(this.cache.scrollContainer);

					var pagination = jQuery(data).find('.pagination-next');

					if (pagination.length) {
						pagination.css('display', 'none');
						this.cache.pagination.replaceWith(pagination);
						this.cache.pagination = jQuery('.pagination-next');
					} else {
						this.cache.loadTrigger.addClass("fade-out");

						setTimeout(() => {
							this.cache.loadTrigger.remove();
						}, 100);
					}

				},
				complete: () => {
					this.cache.loading = false;
					this.cache.loadTrigger.find('i.fa-spin').remove();
				},
				dataType: 'html'
			});
		}

	};

	if (jQuery('[data-infinite-scroll]').length) {
		csAJAXPagination.init();
	}
})();
