'use strict';
(function() {
	// Global Banner Functions
	var csVehicle = {
		/**
		* Stores cached elements
		**/
		cache: {
			gallery_slider: jQuery('.vehicle__gallery-slider'),
			feature_image_wrapper: jQuery('.vehicle__feature-image'),
			feature_image: jQuery('.vehicle__feature-image img'),
			image_preview_btn: jQuery('#vehicle__image-preview'),
			reveal: jQuery('#vehicle__reveal-image'),
			current_image: false
		},
		/**
		* @function
		* Initialises the Banner
		*/
		init: function() {
			this.initSlider();
			this.gravity();

			this.cache.image_preview_btn.on('click', (e) => {
				e.preventDefault();

				this.loadImage();
			});

			this.cache.reveal.find('[data-next]').on('click', (e) => {
				e.preventDefault();

				if (this.cache.current_image === false) {
					return;
				}

				if (!this.cache.current_image.next().length) {
					return;
				}

				this.cache.current_image = this.cache.current_image.next();

				this.loadImage();
				this.cache.trigger('open.zf.reveal');
			});

			this.cache.reveal.find('[data-prev]').on('click', (e) => {
				e.preventDefault();

				if (this.cache.current_image === false) {
					return;
				}

				if (!this.cache.current_image.prev().length) {
					return;
				}

				this.cache.current_image = this.cache.current_image.prev();

				this.loadImage();
				this.cache.reveal.trigger('open.zf.reveal');
			});
		},
		/**
		* @function
		* Initialises the Banner Slider
		*/
		initSlider: function() {

			this.cache.gallery_slider.on('init', () => {
				var activeSlide = this.cache.gallery_slider.find('.slick-active');
				this.cache.current_image = activeSlide;

				this.cache.gallery_slider.find('.cs__image-wrapper').each((index, element) => {
					var tile = jQuery(element);
					tile.css('height', tile.innerWidth() + 'px');
				});
			});

			this.cache.gallery_slider.slick({
				dots: false,
				infinite: true,
				speed: 500,
				slidesToShow: 4,
				slidesToScroll: 1,
				autoplay: false,
				rows: 0,
				cssEase: 'cubic-bezier(0.645, 0.045, 0.355, 1.000)',
				prevArrow: this.cache.feature_image_wrapper.find('.slick-prev'),
				nextArrow: this.cache.feature_image_wrapper.find('.slick-next'),
			});

			this.cache.gallery_slider.on('click', 'a[data-change-featured-image]', (e) => {
				e.preventDefault();
				//this.cache.feature_image.css("background-image", "url('" + jQuery(e.currentTarget).attr("href") + "')");

				var indx = jQuery(e.currentTarget).attr('data-slick-index');
				this.cache.gallery_slider.slick('slickGoTo', parseInt(indx, 10), false);
			});

			// eslint-disable-next-line no-unused-vars
			this.cache.gallery_slider.on('afterChange', (_event, _slick, _currentSlide, _nextSlide) => {
				var activeSlide = this.cache.gallery_slider.find('.slick-active');

				this.cache.current_image = activeSlide;

				this.cache.feature_image.attr('src', activeSlide.attr('href'));
			});
		},
		loadImage: function() {

			if (this.cache.current_image === false) {
				console.log("No Current");
				return;
			}

			var image = new Image();
			image.onload = () => {
				this.cache.reveal.find(".image").css("background-image", "url('" + this.cache.current_image.attr("href") + "')");
				image = null;
			}

			image.src = this.cache.current_image.attr("href");

			if(this.cache.reveal.is(':visible')) {
				return;
			}

			this.cache.reveal.foundation('open');
		},
		/**
		 * @function
		 * Handle hidding prefiled GravityForm fields
		 */
		gravity: function() {
			var form = jQuery('.vehicle__enquire #gform_wrapper_1');

			form.find('.gfield').each((index, el) => {
				el = jQuery(el);

				var inputVal = el.find('input[type=text],input[type=tel],input[type=email]').val();

				if (typeof inputVal !== 'undefined' && inputVal !== '') {
					el.hide();
				}
			});
		}


	};

	if (jQuery('.single-vehicle').length) {
		csVehicle.init();
	}
})();
