'use strict';

// Global Banner Functions
var csBanner = {
	/**
	* Stores cached elements
	**/
	cache: {},
	/**
	* @function
	* Initialises all objects required for the Banner Functions
	* @param {jQuery Element} el - jQuery Banner Element
	*/
	initCache: function(el) {
		this.cache = {
			banner: el,
			slider: el.find('.banner-slider'),
			heights: {
				header: typeof csHeader === 'undefined' ? 0 : csHeader.getHeaderHeight()
			}
		};
	},
	/**
	* @function
	* Initialises the Banner
	*/
	init: function() {
		this.initCache(jQuery('.banner_container'));

		setTimeout(function() {
			csBanner.calculateHeight();
		}, 500);

		jQuery(window).on('resize', csBanner.calculateHeight());

		if (this.cache.slider.length) {
			this.initSlider();
		}
	},
	/**
	* @function
	* Initialises the Banner Slider
	*/
	initSlider: function() {
		this.cache.slider.on('init', () => {
			csBanner.playVideo();
		});

		this.cache.slider.slick({
			dots: false,
			infinite: true,
			speed: 500,
			slidesToShow: 1,
			slidesToScroll: 1,
			autoplay: true,
			autoplaySpeed: 5000,
			rows: 0,
			fade: true,
			cssEase: 'cubic-bezier(0.645, 0.045, 0.355, 1.000)',
			prevArrow: '<span class="slick-arrow-prev"><i class="fal fa-chevron-left"></i></span>',
			nextArrow: '<span class="slick-arrow-next"><i class="fal fa-chevron-right"></i></span>'
		});

		this.cache.slider.on('afterChange', () => {
			csBanner.playVideo();
		});
	},
	/**
	* @function
	* Play current video
	*/
	playVideo: function() {
		this.cache.slider.find('.slick-item.current video').each(function() {
			this.play();
		});
	},
	/**
	* @function
	* Calculate Banner Heights
	*/
	calculateHeight: function() {
		var height = 0,
		_viewport = jQuery(window).height();

		_viewport = _viewport - this.cache.heights.header;

		switch (this.cache.banner.data('banner-height')) {
			case 'two_thirds':
				height = (_viewport / 3 ) * 2;
			break;
			case 'half':
				height = _viewport / 2;
			break;
			case 'full':
				height = _viewport;
			break;
			case 'custom':
				height = this.cache.banner.data('banner-height-custom');
			break;
			case 'third':
			default:
				height = _viewport / 3;
			break;
		}

		if (Foundation.MediaQuery.is('small only')) {
			height = height - 150;
		}

		if (height < 150) {
			height = 150;
		}

		if (typeof csHeader !== 'undefined' && csHeader.isTransparentHeader()) {
			this.cache.banner.find('.banner-item').css('padding-top', this.cache.heights.header + 'px');
		}

		this.cache.banner.height(height + 'px');

	}

};

window.csBanner = csBanner;

jQuery(() => {
	csBanner.init();
});
