// Footer Map Controller
jQuery(function() {
	'use strict';
	var csMaps = function(el) {
		this.geocoder = new google.maps.Geocoder();
		this.map = false;
		this.bounds = new google.maps.LatLngBounds();
		this.infowindow = new google.maps.InfoWindow();
		this.infowindowOpen = false;
		this.markers = [];
		this.defaultLoc = { lat: parseFloat(-30.5016), lng: parseFloat(151.6662) };
		this.cache = {
			element: el,
			search: el.find('.map__search-box input[type=text]'),
			searchBtn: el.find('.map__search-box button'),
			nearby: {
				wrapper: el.find('.map__nearby'),
				title: el.find('.map__nearby h3'),
				content: el.find('.map__nearby p')
			}
		};

		/* eslint-disable */
		this.options = {
			maxZoom: 16,
			minZoom: 4,
			mode: 'WALKING',
			style: [{"featureType":"water","elementType":"geometry","stylers":[{"color":"#e9e9e9"},{"lightness":17}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":20}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#ffffff"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#ffffff"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":16}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":21}]},{"featureType":"poi.park","elementType":"geometry","stylers":[{"color":"#dedede"},{"lightness":21}]},{"elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#ffffff"},{"lightness":16}]},{"elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#333333"},{"lightness":40}]},{"elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#f2f2f2"},{"lightness":19}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#fefefe"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#fefefe"},{"lightness":17},{"weight":1.2}]}]
		};
		/* eslint-enable */

		this.init();
	};

	csMaps.prototype = {

		init: function() {
			this.cache.map = jQuery('<div data-map></div>').appendTo(this.cache.element);
			this.cache.element.data('csMaps', this);

			this.initOptions();
			this.initMap();
			this.initSearcher();

		},
		initOptions: function() {
			if (typeof this.cache.element.attr('max-zoom') !== 'undefined') {
				this.options.maxZoom = 	this.cache.element.attr('max-zoom');
			}

			if (typeof this.cache.element.attr('min-zoom') !== 'undefined') {
				this.options.maxZoom = 	this.cache.element.attr('min-zoom');
			}
		},
		initDirections: function() {
			this.directionsDisplay = new google.maps.DirectionsRenderer();
			this.directionsService = new google.maps.DirectionsService();
			this.directionsDisplay.setMap(this.map);
		},
		initMap: function() {
			var draggable = true;
			var disableDefaultUI = true;
			var scrollwheel = true;
			var navigationControl = true;
			var mapTypeControl = false;
			var fullscreenControl = false;
			var streetviewControl = true;
			var zoomControl = true;
			var _self = this;

			if (typeof this.cache.element !== 'undefined') {
				if (typeof this.cache.element.attr('draggable') !== 'undefined') {
					draggable = (this.cache.element.attr('draggable') === 'true');
				}

				if (typeof this.cache.element.attr('disabledefaultui') !== 'undefined') {
					disableDefaultUI = (this.cache.element.attr('disabledefaultui') === 'true');
				}

				if (typeof this.cache.element.attr('scrollwheel') !== 'undefined') {
					scrollwheel = (this.cache.element.attr('scrollwheel') === 'true');
				}

				if (typeof this.cache.element.attr('navigationControl') !== 'undefined') {
					navigationControl = (this.cache.element.attr('navigationControl') === 'true');
				}

				if (typeof this.cache.element.attr('mapTypeControl') !== 'undefined') {
					mapTypeControl = (this.cache.element.attr('mapTypeControl') === 'true');
				}

				if (typeof this.cache.element.attr('fullscreencontrol') !== 'undefined') {
					fullscreenControl = (this.cache.element.attr('fullscreencontrol') === 'true');
				}

				if (typeof this.cache.element.attr('streetviewcontrol') !== 'undefined') {
					streetviewControl = (this.cache.element.attr('streetviewcontrol') === 'true');
				}

				if (typeof this.cache.element.attr('zoomcontrol') !== 'undefined') {
					zoomControl = (this.cache.element.attr('zoomcontrol') === 'true');
				}
			}

			this.map = new google.maps.Map(this.cache.map.get(0), {
				zoom: 15,
				center: this.defaultLoc,
				draggable: draggable,
				disableDefaultUI: disableDefaultUI,
				scrollwheel: scrollwheel,
				navigationControl: navigationControl,
				mapTypeControl: mapTypeControl,
				fullscreenControl: fullscreenControl,
				streetViewControl: streetviewControl,
				zoomControl: zoomControl,
				scaleControl: true,
				styles: this.options.style
			});

			this.cache.icon = this.getIcon('#014023');
			this.cache.icon_active = this.getIcon('#0d2043');

			google.maps.event.addListenerOnce(this.map, 'idle', function() {
				if (_self.infowindow.getMap()) {
					return;
				}
				_self.fitBounds();
			});

			// Add Markers to map
			this.cache.element.find('[marker]').each(function() {
				var lat = jQuery(this).attr('latitude');
				var lng = jQuery(this).attr('longitude');

				if (typeof lat !== 'undefined' && lat !== false && typeof lng !== 'undefined' && lng !== false) {
					var latlng = new google.maps.LatLng(lat, lng);
					_self.addMarker(latlng, jQuery(this));
				} else {
					var address = jQuery(this).attr('address');
					_self.geocodeMarker(address, jQuery(this));
				}
			});

			if (!this.cache.element.find('[marker]').length) {
				this.bounds.extend(this.defaultLoc);
				this.fitBounds();
			}

		},
		initSearcher: function() {
			var self = this;
			this.cache.searchBtn.on('click', function(e) {
				e.preventDefault();

				self.cache.nearby.wrapper.removeClass('active');
				self.infowindow.close();

				for (var i = 0; i < self.markers.length; i++) {
					self.markers[i].setIcon(self.cache.icon);
				}

				if (self.cache.search.val() === '') {
					return;
				}

				self.geocoder.geocode({
										address: self.cache.search.val(),
										componentRestrictions: {
											country: 'AU'
										}
									}
				, function(results, status) {

					if (status === google.maps.GeocoderStatus.OK) {
						self.cache.search.val(results[0].formatted_address);

						var closest = self.markers.reduce(function(prev, curr) {

							/* eslint-disable max-len */
							var cpos = google.maps.geometry.spherical.computeDistanceBetween(results[0].geometry.location, curr.position);
							var ppos = google.maps.geometry.spherical.computeDistanceBetween(results[0].geometry.location, prev.position);
							/* eslint-enable */

							return cpos < ppos ? curr : prev;

						});

						if (typeof closest === 'undefined' || !closest) {
							return false;
						}

						self.cache.nearby.wrapper.addClass('active');

						closest.setIcon(self.cache.iconActive);

						self.map.setZoom(15);
						self.map.panTo(closest.position);

						self.cache.nearby.title.html(closest.element.find('.map-container__title').html());
						self.cache.nearby.content.html(closest.element.attr('address'));
						self.cache.nearby.content.append('<p>' + closest.element.attr('phone') + '</p>');
					}

					return status;
				});
			});
		},
		getIcon: function(color = '#014023') {

			var size = 30;
			/* eslint-disable */
			var template = ['<?xml version="1.0"?>',
							'<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100">',
							'<path fill="{{color}}" d="M78.2,11.7c-15.6-15.6-40.9-15.6-56.4,0C10.6,22.9,7.5,39,12.2,53C22.6,82.9,50,100,50,100s27.1-17,37.6-46.6 c0-0.1,0.1-0.2,0.1-0.3V53C92.6,39,89.5,22.9,78.2,11.7L78.2,11.7z M58.5,51c-4.7,4.7-12.3,4.7-17,0c-4.7-4.7-4.7-12.3,0-17 c4.7-4.7,12.3-4.7,17,0C63.2,38.7,63.2,46.3,58.5,51z"></path>',
							'</svg>'
				].join('\n');
			/* eslint-enable */

			var svg = template.replace('{{color}}', color);

			var icon = {
				url: 'data:image/svg+xml;charset=UTF-8,' + encodeURIComponent(svg),
				size: new google.maps.Size(size, size),
				scaledSize: new google.maps.Size(size, size),
				anchor: new google.maps.Point(size / 2, size)

			};

			return icon;

		},
		addMarker: function(position, element) {
			var marker = new google.maps.Marker({
				position: position,
				map: this.map,
				icon: this.cache.icon,
				element: element
			});

			// if (element.find('[info-window]').length > 0) {

			// 	var infoWindow = element.find('[info-window]').eq(0);
			// 	var self = this;

			// 	// eslint-disable-next-line no-unused-vars, no-undef
			// 	var info = new SnazzyInfoWindow({
			// 		marker: marker,
			// 		content: `<div class='ja-infobox'>${infoWindow.html()}</div>`,
			// 		placement: 'top',
			// 		closeOnMapClick: true,
			// 		maxWidth: '400',
			// 		closeWhenOthersOpen: true,
			// 		showCloseButton: false,
			// 		callbacks: {
			// 			beforeOpen: function() {
			// 				marker.setIcon(self.cache.icon_active);
			// 			},
			// 			afterClose: function() {
			// 				marker.setIcon(self.cache.icon);
			// 			}
			// 		}
			// 	});
			// }

			this.markers.push(marker);

			this.map.setCenter(position);
			this.bounds.extend(position);
			this.fitBounds();

		},
		geocodeMarker: function(address, element) {

			if (typeof address === 'undefined' || address === false) {
				return;
			}

			var id = element.attr('id');
			var self = this;
			id = id.replace('marker-', '');

			var type = element.attr('marker');

			if (typeof type !== 'undefined' && typeof id !== 'undefined') {
				// Try and cache Geocoded Coordinates
				jQuery.ajax({
					url:	theme.api_url + 'geocode/' + id,
					method:	'GET',
					async:	true,
					data:	{
								content_type: type
							},
					success: function(data) {
						if (typeof data === 'undefined' || data === false) {
							// Fallback to Google Map Geocoding
							self.geocodeAddress(address, element);
						} else {
							data = new google.maps.LatLng(data.latitude, data.longitude);
							self.addMarker(data, element);
						}
					},
					error: function() {
						// Fallback to Google Map Geocoding
						self.geocodeAddress(address, element);
					}
				});
			} else {
				// Fallback to Google Map Geocoding
				this.geocodeAddress(address, element);
			}
		},
		geocodeAddress: function(address, element) {
			var _self = this;
			return this.geocoder.geocode( { address: address }, function(results, status) {
				if (status === google.maps.GeocoderStatus.OK) {
					_self.addMarker(results[0].geometry.location, element);
				} else {
					return;
				}
			});
		},
		fitBounds: function() {
			if (this.markers.length < 0) {
				return;
			}

			if (jQuery('.section_seven-floating-wrapper').length && !Foundation.MediaQuery.is('small only')) {
				this.map.fitBounds(this.bounds, {left: jQuery('.section_seven-floating-wrapper').outerWidth()});
			} else {
				this.map.fitBounds(this.bounds);
			}

			if (this.map.getZoom() < this.options.minZoom) {
				this.map.setZoom(this.options.minZoom);
			}

			if (this.map.getZoom() > this.options.maxZoom) {
				this.map.setZoom(this.options.maxZoom);
			}
		},
		calculateAndDisplayRoute: function() {

			var _options = {
				travelMode: this.options.mode
			};

			if (this.markers.length < 2) {
				return;
			} else if (this.markers.length >= 2) {
				_options.origin = this.markers[0].getPosition();
				_options.destination = this.markers[this.markers.length - 1].getPosition();
			}

			if (this.markers.length >= 3) {
				var _total = this.markers.length - 1;
				_options.waypoints = [];

				for (var i = 1; i < _total; i++) {
					_options.waypoints.push({location: this.markers[i].getPosition()});
				}
			}

			var _self = this;

			this.directionsService.route(_options, function(response, status) {
				if (status === 'OK') {
					_self.directionsDisplay.setDirections(response);
				}
			});
		},
		bounceMarker: function(key) {
			if (this.markers[key]) {
				var _marker = this.markers[key];

				_marker.setAnimation(google.maps.Animation.BOUNCE);

				setTimeout(function() {
					_marker.setAnimation(null);
				}, 700);
			}
		}
	};

	if (typeof google !== 'object' || typeof google.maps !== 'object') {
		console.log('No Google Maps');
		return;
	}

	jQuery('[google-map]').each(function() {
		/* eslint-disable no-new */
		new csMaps(jQuery(this));
		/* eslint-enable */
	});

});
