<?php
// Register menus
register_nav_menus(
	array(
		'main-nav' => __( 'The Main Menu', 'csframeworkwp' ),   // Main nav in header
		'footer-links' => __( 'Footer Links 1', 'csframeworkwp' ), // Secondary nav in footer
		'footer-links-two' => __( 'Footer Links 2', 'csframeworkwp' ), // Secondary nav in footer
		'footer-copy-links' => __( 'Footer Copy Links', 'csframeworkwp' ),
		'mobile-menu'	=> 'Mobile Menu'
	)
);

// The Top Menu
function csframework_top_nav() {

	$header_type = get_field('header_layout', 'option');
	$menuclass = 'vertical medium-horizontal menu';
	$itemswrap = '<ul id="%1$s" class="%2$s" data-responsive-menu="accordion medium-dropdown">%3$s</ul>';

	if ($header_type == 'fw-hamburger') {
	$menuclass = 'menu';
	$itemswrap = '<ul id="%1$s" class="%2$s">%3$s</ul>';
	}

	$current_blog = get_current_blog_id();

	if($current_blog !== 1) {
		switch_to_blog(1);
	}

	wp_nav_menu(array(
		'container' => false,                           // Remove nav container
		'menu_class' => $menuclass,                     // Adding custom nav class
		'items_wrap' => $itemswrap,
		'theme_location' => 'main-nav',        			// Where it's located in the theme
		'depth' => 5,                                   // Limit the depth of the nav
		'fallback_cb' => false,                         // Fallback function (see below)
		'walker' => new Topbar_Menu_Walker()
	));

	if($current_blog !== 1) {
		switch_to_blog($current_blog);
	}
}


// Big thanks to Brett Mason (https://github.com/brettsmason) for the awesome walker
class Topbar_Menu_Walker extends Walker_Nav_Menu {
	private $mega_menu = false;

	function start_lvl(&$output, $depth = 0, $args = Array() ) {
		$indent = str_repeat("\t", $depth);

		$classes = array("menu");

		if($this->mega_menu === true) {
			$classes[] = "mega-menu";
			$classes[] = "grid-x";
			$classes[] = "grid-margin-x";
			$classes[] = "grid-margin-y";
		}

		$output .= "\n$indent<ul class=\"". implode(" ", $classes) ."\">\n";

		if($this->mega_menu === true && !empty($this->mega_menu_title)) {
			$output .= "<div class=\"cell medium-12\"><h3>" . $this->mega_menu_title . "</h3></div>";
		}
	}

	public function end_el( &$output, $item, $depth = 0, $args = array() ) {
		if($this->mega_menu === true && $depth == 0) {
			$this->mega_menu = false;
			$this->mega_menu_title = false;
		}
	}

	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
	    if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
	        $t = '';
	        $n = '';
	    } else {
	        $t = "\t";
	        $n = "\n";
	    }
	    $indent = ( $depth ) ? str_repeat( $t, $depth ) : '';

	    $classes   = empty( $item->classes ) ? array() : (array) $item->classes;
	    $classes[] = 'menu-item-' . $item->ID;

	    if(get_field("enable_mega_menu", $item->ID)) {
			$classes[] = "mega-menu-parent";
			$this->mega_menu = true;
			$this->mega_menu_title = get_field("mega_menu_title", $item->ID);
	    }

	     if($this->mega_menu && $depth == 1) {
		    $cell_size = get_field("column_size", $item->ID);
		    $classes[] = 'cell';
		    $classes[] = 'medium-' . $cell_size;
	    }



	    /**
	     * Filters the arguments for a single nav menu item.
	     *
	     * @since 4.4.0
	     *
	     * @param stdClass $args  An object of wp_nav_menu() arguments.
	     * @param WP_Post  $item  Menu item data object.
	     * @param int      $depth Depth of menu item. Used for padding.
	     */
	    $args = apply_filters( 'nav_menu_item_args', $args, $item, $depth );

	    /**
	     * Filters the CSS classes applied to a menu item's list item element.
	     *
	     * @since 3.0.0
	     * @since 4.1.0 The `$depth` parameter was added.
	     *
	     * @param string[] $classes Array of the CSS classes that are applied to the menu item's `<li>` element.
	     * @param WP_Post  $item    The current menu item.
	     * @param stdClass $args    An object of wp_nav_menu() arguments.
	     * @param int      $depth   Depth of menu item. Used for padding.
	     */
	    $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
	    $class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

	    /**
	     * Filters the ID applied to a menu item's list item element.
	     *
	     * @since 3.0.1
	     * @since 4.1.0 The `$depth` parameter was added.
	     *
	     * @param string   $menu_id The ID that is applied to the menu item's `<li>` element.
	     * @param WP_Post  $item    The current menu item.
	     * @param stdClass $args    An object of wp_nav_menu() arguments.
	     * @param int      $depth   Depth of menu item. Used for padding.
	     */
	    $id = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args, $depth );
	    $id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

	    $output .= $indent . '<li' . $id . $class_names . '>';

	    $atts           = array();
	    $atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
	    $atts['target'] = ! empty( $item->target ) ? $item->target : '';
	    if ( '_blank' === $item->target && empty( $item->xfn ) ) {
	        $atts['rel'] = 'noopener noreferrer';
	    } else {
	        $atts['rel'] = $item->xfn;
	    }
	    $atts['href']         = ! empty( $item->url ) ? $item->url : '';
	    $atts['aria-current'] = $item->current ? 'page' : '';

	    /**
	     * Filters the HTML attributes applied to a menu item's anchor element.
	     *
	     * @since 3.6.0
	     * @since 4.1.0 The `$depth` parameter was added.
	     *
	     * @param array $atts {
	     *     The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.
	     *
	     *     @type string $title        Title attribute.
	     *     @type string $target       Target attribute.
	     *     @type string $rel          The rel attribute.
	     *     @type string $href         The href attribute.
	     *     @type string $aria_current The aria-current attribute.
	     * }
	     * @param WP_Post  $item  The current menu item.
	     * @param stdClass $args  An object of wp_nav_menu() arguments.
	     * @param int      $depth Depth of menu item. Used for padding.
	     */
	    $atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );

	    $attributes = '';
	    foreach ( $atts as $attr => $value ) {
	        if ( ! empty( $value ) ) {
	            $value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
	            $attributes .= ' ' . $attr . '="' . $value . '"';
	        }
	    }

	    /** This filter is documented in wp-includes/post-template.php */
	    $title = apply_filters( 'the_title', $item->title, $item->ID );

	    /**
	     * Filters a menu item's title.
	     *
	     * @since 4.4.0
	     *
	     * @param string   $title The menu item's title.
	     * @param WP_Post  $item  The current menu item.
	     * @param stdClass $args  An object of wp_nav_menu() arguments.
	     * @param int      $depth Depth of menu item. Used for padding.
	     */
	    $title = apply_filters( 'nav_menu_item_title', $title, $item, $args, $depth );

	    $item_output  = $args->before;


	    $item_output .= '<a' . $attributes . '>';

	    if(!empty($img = get_field("feature_image", $item->ID))) {
		    $feature_image = wp_get_attachment_image_url($img, "large");
		    $item_output .= "<div class=\"feature-image\" style=\"background-image: url('$feature_image')\"></div>";
		}

		if($this->mega_menu) {
			$item_output .= '<span class="title">';
 		}

		$item_output .= $args->link_before . $title . $args->link_after;

		if($this->mega_menu) {
			$item_output .= '</span>';

			if(!empty($content = get_field("content", $item->ID))) {
				$item_output .= '<p class="menu-item-content">' . $content . '</p>';
			}


			if($depth > 0) {
				$item_output .= '<span class="button secondary">Shop ' . $title . '</span>';
			}
		}

	    $item_output .= '</a>';

	    $item_output .= $args->after;

	    /**
	     * Filters a menu item's starting output.
	     *
	     * The menu item's starting output only includes `$args->before`, the opening `<a>`,
	     * the menu item's title, the closing `</a>`, and `$args->after`. Currently, there is
	     * no filter for modifying the opening and closing `<li>` for a menu item.
	     *
	     * @since 3.0.0
	     *
	     * @param string   $item_output The menu item's starting HTML output.
	     * @param WP_Post  $item        Menu item data object.
	     * @param int      $depth       Depth of menu item. Used for padding.
	     * @param stdClass $args        An object of wp_nav_menu() arguments.
	     */
	    $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
}

//Add Search Icon to Menu
function csframework_customiseMainMenu( $menu_items, $args ) {

	if ($args->theme_location == 'main-nav' && get_field("search", "options")) {
		// Adding Search to menu
		$menu_items .= '<li class="menu-item"><a href="#" data-js-searchtrigger ><span><i class="far fa-search" aria-hidden="true"></i></span></a></li>';
	}

	return $menu_items;
}

add_filter( 'wp_nav_menu_items', 'csframework_customiseMainMenu', 10, 2 );


// The Off Canvas Menu
function csframework_off_canvas_nav() {
	 wp_nav_menu(array(
		'container' => false,                           // Remove nav container
		'menu_class' => 'vertical menu',       // Adding custom nav class
		'items_wrap' => '<ul id="%1$s" class="%2$s" data-accordion-menu>%3$s</ul>',
		'theme_location' => 'mobile-menu',        			// Where it's located in the theme
		'depth' => 5,                                   // Limit the depth of the nav
		'fallback_cb' => false,                         // Fallback function (see below)
		'walker' => new Off_Canvas_Menu_Walker()
	));
}

class Off_Canvas_Menu_Walker extends Walker_Nav_Menu {
	function start_lvl(&$output, $depth = 0, $args = Array() ) {
		$indent = str_repeat("\t", $depth);
		$output .= "\n$indent<ul class=\"vertical menu\">\n";
	}
}

// Social Menu
function csframework_social_links() {
	 wp_nav_menu(array(
		'menu' => __( 'Social Links', 'csframeworkwp' ),    // Nav name
		'sort_column' => 'menu_order',
		'container_class' => 'menu-social-container',                        // Remove nav container
		'menu_class' => 'social-menu',       // Adding custom nav class
		'link_before' => '<span>',
		'link_after' => '</span>',
		'items_wrap' => '<ul class="%2$s">%3$s</ul>',
		'theme_location' => 'social-menu',                 // Where it's located in the theme
		'depth' => 0,                                   // Limit the depth of the nav
		'fallback_cb' => '',

	));
}

// The Footer Menu
function csframework_footer_links() {
	wp_nav_menu(array(
		'container' => 'false',                         // Remove nav container
		'menu' => __( 'Footer Links', 'csframeworkwp' ),   	// Nav name
		'menu_class' => 'menu',      					// Adding custom nav class
		'theme_location' => 'footer-links',             // Where it's located in the theme
		'depth' => 0,                                   // Limit the depth of the nav
		'fallback_cb' => ''  							// Fallback function
	));
} /* End Footer Menu */

// The Footer Menu Two
function csframework_footer_links_two() {
	wp_nav_menu(array(
		'container' => 'false',                         // Remove nav container
		'menu' => __( 'Footer Links', 'csframeworkwp' ),   	// Nav name
		'menu_class' => 'menu',      					// Adding custom nav class
		'theme_location' => 'footer-links-two',             // Where it's located in the theme
		'depth' => 0,                                   // Limit the depth of the nav
		'fallback_cb' => ''  							// Fallback function
	));
}

// The Footer Menu Two
function csframework_footer_copy_links() {
	wp_nav_menu(array(
		'container' => 'false',                         // Remove nav container
		'menu' => __( 'Footer Links', 'csframeworkwp' ),   	// Nav name
		'menu_class' => 'menu',      					// Adding custom nav class
		'theme_location' => 'footer-copy-links',             // Where it's located in the theme
		'depth' => 0,                                   // Limit the depth of the nav
		'fallback_cb' => ''  							// Fallback function
	));
}

// Header Fallback Menu
function csframework_main_nav_fallback() {
	wp_page_menu( array(
		'show_home' => true,
		'menu_class' => '',      						// Adding custom nav class
		'include'     => '',
		'exclude'     => '',
		'echo'        => true,
		'link_before' => '',                           // Before each link
		'link_after' => ''                             // After each link
	) );
}

// Footer Fallback Menu
function csframework_footer_links_fallback() {
	/* You can put a default here if you like */
}

// Add Foundation active class to menu
function required_active_nav_class( $classes, $item ) {
	if ( $item->current == 1 || $item->current_item_ancestor == true ) {
		$classes[] = 'active';
	}
	return $classes;
}
add_filter( 'nav_menu_css_class', 'required_active_nav_class', 10, 2 );

function csframework_get_header_style() {

	if(get_field("transparent_navigation_bar", "options") && is_front_page()) {
		return "transparent";
	}
}


function csframework_filter_mobile_menu($items, $menu, $args) {
	remove_filter( current_filter(), __FUNCTION__, 10, 3 );

	$new_items = array();

	$menu_ids = array();

	foreach($items as $item) {

		if(property_exists($item, "post_title") && ($item->post_title == "[Row]" || $item->post_title == "[Column]" || $item->post_title == "[Custom]")) {
			$menu_ids[$item->ID] = $item->menu_item_parent;
			continue;
		}

		$new_items[] = $item;
	}

	foreach($new_items as $key=>$item) {
		if(property_exists($item, "menu_item_parent") && isset($menu_ids[$item->menu_item_parent])) {
			$item->menu_item_parent = $menu_ids[intval($item->menu_item_parent)];
			$new_items[$key] = $item;
		}
	}

	return $new_items;
}

function wpa108544_nav_menu_args( $args ){
	// check if it's the location we want the filter applied to
	if('mobile-menu' == $args['theme_location']){
		add_filter( 'wp_get_nav_menu_items', 'csframework_filter_mobile_menu', 10, 3 );
	}

	return $args;
}
//add_filter( 'wp_nav_menu_args', 'wpa108544_nav_menu_args' );
