<?php
	
// Adding WP Functions & Theme Support
function csframework_theme_support() {

	// Add Custom Logo Support
	add_theme_support( 'custom-logo', array(
		'height'      => 80,
		'width'       => 250,
		'flex-height' => true,
		'flex-width'  => true,
		'header-text' => array( 'site-title', 'site-description' ),
	) );

	// Add WP Thumbnail Support
	add_theme_support( 'post-thumbnails' );
	
	// Default thumbnail size
	set_post_thumbnail_size(125, 125, true);

	// Add RSS Support
	add_theme_support( 'automatic-feed-links' );
	
	// Add Support for WP Controlled Title Tag
	add_theme_support( 'title-tag' );
	
	// Add HTML5 Support
	add_theme_support( 'html5', 
	         array( 
	         	'comment-list', 
	         	'comment-form', 
	         	'search-form', 
	         ) 
	);
	
	// Adding post format support
	 add_theme_support( 'post-formats',
		array(
			'aside',             // title less blurb
			'gallery',           // gallery of images
			'link',              // quick link to other site
			'image',             // an image
			'quote',             // a quick quote
			'status',            // a Facebook like status update
			'video',             // video
			'audio',             // audio
			'chat'               // chat transcript
		)
	); 
	
	// Set the maximum allowed width for any content in the theme, like oEmbeds and images added to posts.
	$GLOBALS['content_width'] = apply_filters( 'csframework_theme_support', 1200 );	
	
	register_sidebar( array(
		'name' => 'Footer Menu',
		'id' => 'footer-menu-1',
		'description' => 'Appears in the footer area',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	
	
} /* end theme support */

add_action( 'after_setup_theme', 'csframework_theme_support' );

//SVG Support
function cc_mime_types($mimes) {

	if(current_user_can("manage_options")){
		$mimes['svg'] = 'image/svg+xml';
	}
	return $mimes;
}
add_filter('upload_mimes', 'cc_mime_types');



function csframework_color_scheme() {
	?>
	
	<meta class="csframework-color-scheme primary">
	<meta class="csframework-color-scheme secondary">
	<meta class="csframework-color-scheme dark-gray">
	<meta class="csframework-color-scheme medium-gray">
	<meta class="csframework-color-scheme light-gray">
	<meta class="csframework-color-scheme black">
	<meta class="csframework-color-scheme white">
	
	<?php
}


function csframework_acf_footer() {
	
?>
<script type="text/javascript">
	(function($) {
		
		var meta = jQuery("meta.csframework-color-scheme");
		
		if(meta.length) {
			acf.add_filter('color_picker_args', function( args, $field ){
				
				args.palettes = [];
				
				meta.each(function(){
					args.palettes.push(jQuery(this).css('backgroundColor'));
				});
				
				// return
				return args;
						
			});
		}
	})(jQuery);	
</script>
<?php
}

add_action('acf/input/admin_footer', 'csframework_acf_footer');

add_action('get_header', 'my_filter_head');

function my_filter_head() {
	remove_action('wp_head', '_admin_bar_bump_cb');
}